@@ -1,4 +1,5 @@
 from abc import ABC, abstractmethod
+from datetime import datetime
 from typing import (
     cast,
     List,
@@ -25,16 +26,22 @@ MessageRole = Literal[
     "system",
     "user",
     "assistant",
-    "system name=example_user",
-    "system name=example_assistant",
+    "example_user",  # Will add prefix (system name=) in prepare_prompt
+    "example_assistant",
 ]
 
 
 # Models
+class MessageDict(TypedDict):
+    role: str
+    content: str
+
+
 class Message(pydantic.BaseModel):
     """Container for a single chatml prefix message"""
 
     role: MessageRole
+    timestamp: datetime = pydantic.Field(default_factory=datetime.utcnow)
 
     # Content / Template
     content: Optional[str] = None
@@ -44,6 +51,11 @@ class Message(pydantic.BaseModel):
     # Check template variables
     check: bool = False
 
+    # Stickiness
+    sticky: bool = False
+    label: str = ""
+    sticky_position: Literal["top", "bottom"] = "bottom"
+
     # Should forward downstream
     forward: bool = False
 
@@ -54,6 +66,11 @@ class Message(pydantic.BaseModel):
         check = values["check"]
         template_string = values.pop("template")
         variables = values.pop("variables")
+        sticky = values["sticky"]
+        label = values["label"]
+
+        # Check that sticky messages have an id
+        assert not (sticky ^ bool(label)), "Sticky must be set with label"
 
         # Check that correct values set
         template_set = bool(template_string) and (variables is not None)
@@ -67,10 +84,10 @@ class Message(pydantic.BaseModel):
 
         return values
 
-
-class MessageDict(TypedDict):
-    role: MessageRole
-    content: str
+    def dict(self, **kwargs) -> MessageDict:
+        # Include role and content
+        kwargs.setdefault("include", {"role", "content"})
+        return cast(MessageDict, super().dict(**kwargs))
 
 
 # Abstract classes
@@ -84,7 +101,7 @@ class BaseMessageCollection(ABC):
     async def get_dicts(self) -> List[MessageDict]:
         messages = await self.get()
 
-        return [
-            cast(MessageDict, message.dict(include={"role", "content"}))
-            for message in messages
-        ]
+        # Convert
+        message_dicts = [cast(MessageDict, message.dict()) for message in messages]
+
+        return message_dicts
